@@ -15,6 +15,10 @@ class File(FileOrDirectory):
     def __init__(self, path):
         self.path = path
 
+    def delete(self):
+        if self.exists:
+            os.remove(self.path)
+
     @property
     def ext(self):
         return self.name.split('.')[-1]
